package VMOMI::CryptoManagerKmip;
use parent 'VMOMI::CryptoManager';

use strict;
use warnings;

our @class_ancestors = (
    'ManagedObject',
    'CryptoManager',
);

our @class_members = ( 
	['kmpiServers', 'KmipClusterInfo', 1, 0],
);

sub get_class_ancestors {
    return @class_ancestors;
}

sub get_class_members {
    my $class = shift;
    my @super_members = $class->SUPER::get_class_members();
    return (@super_members, @class_members);
}

1;